* Arun R Bharadwaj <[email protected]> [2009-09-22 16:55:27]:
Hi,
I have done the following experiments and have posted the results
below.
Average of 5 iterations:
------------------------------------------------------------------------------
------------------------------------------------------------------------------
Kernbench make -j16 results on a
16 core x86 machine _with_deep_sleep_ support (C1,C2,C3)
Without the patches applied With the patches applied
31.8s 30.4s
------------------------------------------------------------------------------
------------------------------------------------------------------------------
Kernbench make -j8 results on a
8 core x86 machine _without_deep_sleep_ support (only mwait)
Without the patches applied With the patches applied
20.2s 20.4s
------------------------------------------------------------------------------
------------------------------------------------------------------------------
Kernbench make -j8 results on a 8 core _dedicated_lpar_pSeries_ machine
Without the patches applied With the patches applied
4m, 37s 4m, 36s
------------------------------------------------------------------------------
------------------------------------------------------------------------------
Please let me know if any other kind of testing is necessary.
Based on the feedback, I will post out the next iteration with a few
minor bug fixes.
thanks,
arun
_______________________________________________
Linuxppc-dev mailing list
[email protected]
https://lists.ozlabs.org/listinfo/linuxppc-dev